mvn.sim.2.cps: Simulate multivariate normal data with 2 change points
Description
This function simulates a multivariate normal data set with 2
change points in the network structure.
Usage
mvn.sim.2.cps(nobs, n_ser, seed = 101)
Arguments
nobs
A positive integer, which defines the length of the time series.
It must be a multiple of 3 since change points occur at time points T/3
and 2T/3.
n_ser
A positive integer number indicating the dimensionality of the
time series. n_ser must be equal to or larger than 8 as mvn.sim.2.cps
generates 3 different network structures among 8 connected nodes. The remaining
variables are generated as independent data.
seed
A positive integer with default value equal to 101.
It is used to ensure reproducibility.
Value
A nobs * n_ser matrix with 2 change points
at time points nobs/3+1 and nobs*2/3+1.